@@ -1,28 +1,15 @@
 /*
-  Copyright (C) 2002 Rik Hemsley (rikkus) <rik@kde.org>
-  Copyright (C) 2002-2005 Benjamin Meyer <ben-devel@meyerhome.net>
-  Copyright (C) 2002-2004 Nadeem Hasan <nhasan@nadmm.com>
+    SPDX-FileCopyrightText: 2002 Rik Hemsley (rikkus) <rik@kde.org>
+    SPDX-FileCopyrightText: 2002-2005 Benjamin Meyer <ben-devel@meyerhome.net>
+    SPDX-FileCopyrightText: 2002-2004 Nadeem Hasan <nhasan@nadmm.com>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KCDDB_CDINFO_H
 #define KCDDB_CDINFO_H
 
-#include <kcddb_export.h>
+#include "kcddb_export.h"
 #include <QStringList>
 #include <QVariant>
 
